@@ -101,6 +101,8 @@ PyObject *pyg_integer_richcompare(PyObject *v,
                                   PyObject *w,
                                   int op);
 
+gboolean pyg_gerror_exception_check(GError **error);
+
 /* from pygtype.h */
 extern PyTypeObject PyGTypeWrapper_Type;
 
@@ -143,6 +145,13 @@ extern PyTypeObject PyGInterface_Type;
 extern PyTypeObject PyGProps_Type;
 extern PyTypeObject PyGPropsDescr_Type;
 extern PyTypeObject PyGPropsIter_Type;
+
+  /* Data that belongs to the GObject instance, not the Python wrapper */
+struct _PyGObjectData {
+    PyTypeObject *type; /* wrapper type for this instance */
+    GSList *closures;
+};
+
 void          pygobject_register_class   (PyObject *dict,
 					  const gchar *type_name,
 					  GType gtype, PyTypeObject *type,
@@ -208,76 +217,12 @@ extern PyObject * pyg_enum_add        (PyObject *   module,
 extern PyObject * pyg_enum_from_gtype (GType        gtype,
 				       int          value);
 
-/* pygmainloop */
-
-typedef struct {
-    PyObject_HEAD
-    GMainLoop *loop;
-    GSource *signal_source;
-} PyGMainLoop;
-
-extern PyTypeObject PyGMainLoop_Type;
-
-/* pygmaincontext */
-
-typedef struct {
-    PyObject_HEAD
-    GMainContext *context;
-} PyGMainContext;
-
-extern PyTypeObject PyGMainContext_Type;
-PyObject * pyg_main_context_new (GMainContext *context);
-
 /* pygparamspec */
 
 extern PyTypeObject PyGParamSpec_Type;
 PyObject * pyg_param_spec_new (GParamSpec *pspec);
 
-/* pygiochannel.c */
-extern PyTypeObject PyGIOChannel_Type;
-
-/* pygsource.c */
-extern PyTypeObject PyGSource_Type;
-extern PyTypeObject PyGIdle_Type;
-extern PyTypeObject PyGTimeout_Type;
-extern PyTypeObject PyGPollFD_Type;
-
-typedef struct
-{
-    PyObject_HEAD
-    GPollFD pollfd;
-    PyObject *fd_obj;
-} PyGPollFD;
-
-  /* Data that belongs to the GObject instance, not the Python wrapper */
-struct _PyGObjectData {
-    PyTypeObject *type; /* wrapper type for this instance */
-    GSList *closures;
-};
-
-/* pygoption.c */
-extern PyTypeObject PyGOptionContext_Type;
-extern PyTypeObject PyGOptionGroup_Type;
-
-typedef struct {
-    PyObject_HEAD
-    GOptionGroup *group;
-    gboolean other_owner, is_in_context;
-    PyObject *callback;
-    GSList *strings; /* all strings added with the entries, are freed on 
-                        GOptionGroup.destroy() */
-} PyGOptionGroup;
-
-typedef struct {
-    PyObject_HEAD
-    PyGOptionGroup *main_group;
-    GOptionContext *context;
-} PyGOptionContext;
-
-PyObject * pyg_option_context_new (GOptionContext * context);
-PyObject * pyg_option_group_new (GOptionGroup * group);
-GOptionGroup *pyg_option_group_transfer_group(PyGOptionGroup *self);
-
+/* pygtype.c */
 extern GHashTable *custom_type_registration;
 void pyg_type_register_custom_callback(const gchar *type_name,
 				       PyGTypeRegistrationFunction callback,
